@@ -17,9 +17,6 @@ def run():
     parser.add_argument(
         '--encoding', action='store', help="Encoding for the output file", default=None
     )
-    # Maybe use cache for every request
-    # And use another dump option for just raw posts??
-    parser.add_argument('--cache', type=str, help="Cache HTTP responses in this directory")
 
     args = parser.parse_args()
 
