@@ -47,7 +47,8 @@ class PostExtractor:
     image_regex_lq = re.compile(r"background-image: url\('(.+)'\)")
     video_thumbnail_regex = re.compile(r"background: url\('(.+)'\)")
     post_url_regex = re.compile(r'/story.php\?story_fbid=')
-    video_post_url_regex = re.compile(r'https://www.facebook.com/.+/videos/.+/(.+)/.+')
+    video_post_url_regex = re.compile(r'/.+/videos/.+/(.+)/.+')
+    video_id_regex = re.compile(r'{&quot;videoID&quot;:&quot;([0-9]+)&quot;')
 
     shares_and_reactions_regex = re.compile(
         r'<script nonce=.*>.*bigPipe.onPageletArrive\((?P<data>\{.*RelayPrefetchedStreamCache.*\})\);'
@@ -75,11 +76,13 @@ class PostExtractor:
             'image': None,
             'video': None,
             'video_thumbnail': None,
+            'video_id': None,
             'likes': None,
             'comments': None,
             'shares': None,
             'post_url': None,
             'link': None,
+            'user_id': None,
         }
 
     def extract_post(self) -> Post:
@@ -95,8 +98,10 @@ class PostExtractor:
             self.extract_shares,
             self.extract_post_url,
             self.extract_link,
+            self.extract_user_id,
             self.extract_video,
             self.extract_video_thumbnail,
+            self.extract_video_id,
         ]
 
         post = self.make_new_post()
@@ -200,6 +205,9 @@ class PostExtractor:
 
         return None
 
+    def extract_user_id(self) -> PartialPost:
+        return {'user_id': self.data_ft['content_owner_id_new']}
+
     def extract_image(self) -> PartialPost:
         image_link = self.extract_photo_link()
         if image_link is not None:
@@ -247,7 +255,7 @@ class PostExtractor:
 
             elif video_post_match:
                 video_post_id = video_post_match.group(1)
-                url = utils.urljoin(FB_BASE_URL, f'watch/?v={video_post_id}')
+                url = utils.urljoin(FB_BASE_URL, f'watch?v={video_post_id}')
                 return {'post_url': url}
         return None
 
@@ -362,7 +370,7 @@ class PostExtractor:
         }
         if 'youtube_dl_verbose' in self.options:
             ydl_opts.quiet = False
-            
+
         try:
             post_id = self.post.get('post_id')
             video_page = 'https://www.facebook.com/' + post_id
@@ -383,6 +391,12 @@ class PostExtractor:
             return {'video_thumbnail': utils.decode_css_url(match.groups()[0])}
         return None
 
+    def extract_video_id(self):
+        match = self.video_id_regex.search(self.element.html)
+        if match:
+            return {'video_id': match.groups()[0]}
+        return None
+
     def parse_share_and_reactions(self, html: str):
         bad_jsons = self.shares_and_reactions_regex.findall(html)
         for bad_json in bad_jsons:
